pub struct SerializedFileCommonHeader { /* private fields */ }Trait Implementations
Sourceimpl BinRead for SerializedFileCommonHeader
impl BinRead for SerializedFileCommonHeader
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_options: &ReadOptions,
__binrw_generated_var_arguments: Self::Args,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_options: &ReadOptions, __binrw_generated_var_arguments: Self::Args, ) -> BinResult<Self>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
Read
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourcefn read_le_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
fn read_le_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
Read
Self from the reader, assuming little-endian byte order, using
the given arguments. Read moreSourceimpl BinWrite for SerializedFileCommonHeader
impl BinWrite for SerializedFileCommonHeader
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_options: &WriteOptions,
__binrw_generated_var_arguments: Self::Args,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_options: &WriteOptions, __binrw_generated_var_arguments: Self::Args, ) -> BinResult<()>
Sourcefn write<W>(&self, writer: &mut W) -> Result<(), Error>
fn write<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer using default arguments. Read moreSourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_args<W>(&self, writer: &mut W, args: Self::Args) -> Result<(), Error>
fn write_args<W>(&self, writer: &mut W, args: Self::Args) -> Result<(), Error>
Write
Self to the writer using the given arguments. Read moreSourceimpl Debug for SerializedFileCommonHeader
impl Debug for SerializedFileCommonHeader
Sourceimpl ReadEndian for SerializedFileCommonHeader
impl ReadEndian for SerializedFileCommonHeader
Sourceconst ENDIAN: EndianKind
const ENDIAN: EndianKind
The endianness of the type.
Sourceimpl WriteEndian for SerializedFileCommonHeader
impl WriteEndian for SerializedFileCommonHeader
Sourceconst ENDIAN: EndianKind
const ENDIAN: EndianKind
The endianness of the type.
impl Eq for SerializedFileCommonHeader
impl StructuralPartialEq for SerializedFileCommonHeader