pub struct Object {
pub path_id: i64,
pub byte_start: u32,
pub byte_size: u32,
pub type_id: i32,
pub class_id: u16,
pub script_type_index: i16,
pub stripped: u8,
}Fields
path_id: i64byte_start: u32byte_size: u32type_id: i32class_id: u16script_type_index: i16stripped: u8Trait Implementations
Sourceimpl BinRead for Object
impl BinRead for Object
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_options: &ReadOptions,
__binrw_generated_var_arguments: Self::Args,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_options: &ReadOptions, __binrw_generated_var_arguments: Self::Args, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourcefn read_le_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
fn read_le_args<R>(reader: &mut R, args: Self::Args) -> Result<Self, Error>
Read
Self from the reader, assuming little-endian byte order, using
the given arguments. Read moreSourceimpl BinWrite for Object
impl BinWrite for Object
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_options: &WriteOptions,
__binrw_generated_var_arguments: Self::Args,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_options: &WriteOptions, __binrw_generated_var_arguments: Self::Args, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreimpl StructuralPartialEq for Object